
# Changes

## 2022.7.23

* Bumped dependecies for development and test
* Moved from sphinx to mkdocs
* Moved documentation to https://codes.dilettant.life/docs/partitionsets/
* Moved normative source repo to https://git.sr.ht/~sthagen/partitionsets
* Dropped support for any python version below 3.8 (please use partitionsets==0.1.2) 

## 2021.5.8 (0.2.0 unpublished)

* Added python 3.9 compatibility.
* Changed name of script to partition-sets (leads to bump in minor version)
* Addition of docker image building (shagen/partition-sets)
* Removal of defunct badges from documentation
* Removal of decfunct CI/CD service files

## 2019.11.10 (0.1.2)

* License harmony: BSD to MIT, update source repository user name forming part of the paths / URLs, brushed off bit rot, publication to pypi.

## 2013.3.4 (0.1.1)

* First release on PyPI.
